# eric7.WebBrowser.GreaseMonkey.GreaseMonkeyConfiguration.GreaseMonkeyConfigurationListDelegate

Module implementing a delegate for the special list widget for GreaseMonkey scripts.

### Global Attributes

None

### Classes

GreaseMonkeyConfigurationListDelegate | Class implementing a delegate for the special list widget for GreaseMonkey scripts.

### Functions

None

## GreaseMonkeyConfigurationListDelegate

Class implementing a delegate for the special list widget for GreaseMonkey scripts.

### Derived from

QStyledItemDelegate

### Class Attributes

CheckBoxSize
IconSize
ItemWidth
MinPadding
RemoveIconSize

### Class Methods

None

### Methods

GreaseMonkeyConfigurationListDelegate | Constructor
padding | Public method to get the padding used.
paint | Public method to paint the specified list item.
sizeHint | Public method to get a size hint for the specified list item.

### Static Methods

None

#### GreaseMonkeyConfigurationListDelegate (Constructor)

GreaseMonkeyConfigurationListDelegate(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### GreaseMonkeyConfigurationListDelegate.padding

padding()

Public method to get the padding used.

Return:
  padding used

Return Type:
  int

#### GreaseMonkeyConfigurationListDelegate.paint

paint(painter, option, index)

Public method to paint the specified list item.

painter (QPainter)
  painter object to paint to
option (QStyleOptionViewItem)
  style option used for painting
index (QModelIndex)
  model index of the item

#### GreaseMonkeyConfigurationListDelegate.sizeHint

sizeHint(option, index)

Public method to get a size hint for the specified list item.

option (QStyleOptionViewItem)
  style option used for painting
index (QModelIndex)
  model index of the item

Return:
  size hint

Return Type:
  QSize

Up